@@ -26,6 +26,8 @@ from .base import DyffBaseModel, JsonMergePatchSemantics
 from .platform import (
     AnalysisBase,
     AnalysisScope,
+    ChallengeContent,
+    ChallengeTaskBase,
     ConcernBase,
     DatasetBase,
     DataView,
@@ -60,12 +62,14 @@ class DyffRequestDefaultValidators(DyffBaseModel):
     """
 
     @pydantic.model_validator(mode="after")
-    def _require_datetime_timezone_aware(cls, values):
-        for k, v in values.__dict__.items():
+    def _require_datetime_timezone_aware(self):
+        for k, v in self.__dict__.items():
             if isinstance(v, datetime):
                 if v.tzinfo is None:
-                    raise ValueError(f"{cls.__qualname__}.{k}: timezone not set")
-        return values
+                    raise ValueError(
+                        f"{self.__class__.__qualname__}.{k}: timezone not set"
+                    )
+        return self
 
 
 class DyffRequestBase(SchemaVersion, DyffRequestDefaultValidators):
@@ -136,6 +140,17 @@ class ArtifactCreateRequest(DyffEntityCreateRequest):
     pass
 
 
+class ChallengeCreateRequest(DyffEntityCreateRequest):
+    content: ChallengeContent = pydantic.Field(
+        default_factory=ChallengeContent,
+        description="Content of the challenge view in the Dyff App.",
+    )
+
+
+class ChallengeTaskCreateRequest(DyffEntityCreateRequest, ChallengeTaskBase):
+    pass
+
+
 class ConcernCreateRequest(DyffEntityCreateRequest, ConcernBase):
     @pydantic.field_validator("documentation", check_fields=False)
     def _validate_documentation(
@@ -171,14 +186,14 @@ class InferenceServiceCreateRequest(DyffEntityCreateRequest, InferenceServiceBas
     )
 
     @pydantic.model_validator(mode="after")
-    def check_runner_and_image_specified(cls, values):
-        if values.runner is None:
+    def check_runner_and_image_specified(self):
+        if self.runner is None:
             raise ValueError("must specify .runner in new inference services")
-        image = values.runner.image is not None
-        imageRef = values.runner.imageRef is not None
+        image = self.runner.image is not None
+        imageRef = self.runner.imageRef is not None
         if sum([image, imageRef]) != 1:
             raise ValueError("must specify exactly one of .runner.{image, imageRef}")
-        return values
+        return self
 
 
 class InferenceSessionCreateRequest(DyffEntityCreateRequest, InferenceSessionBase):
@@ -213,14 +228,14 @@ class EvaluationCreateRequest(DyffEntityCreateRequest, EvaluationBase):
     )
 
     @pydantic.model_validator(mode="after")
-    def check_session_exactly_one(cls, values):
-        session = values.inferenceSession is not None
-        session_ref = values.inferenceSessionReference is not None
+    def check_session_exactly_one(self):
+        session = self.inferenceSession is not None
+        session_ref = self.inferenceSessionReference is not None
         if not (session ^ session_ref):
             raise ValueError(
                 "must specify exactly one of {inferenceSession, inferenceSessionReference}"
             )
-        return values
+        return self
 
     @staticmethod
     def repeat_of(evaluation: Evaluation) -> EvaluationCreateRequest:
@@ -286,6 +301,10 @@ class ReportCreateRequest(DyffEntityCreateRequest, ReportBase):
 # ----------------------------------------------------------------------------
 
 
+class ChallengeContentEditRequest(DyffRequestBase, commands.EditChallengeContentPatch):
+    pass
+
+
 class DocumentationEditRequest(
     DyffRequestBase, commands.EditEntityDocumentationAttributes
 ):
@@ -471,6 +490,9 @@ __all__ = [
     "ArtifactCreateRequest",
     "ArtifactQueryRequest",
     "AuditQueryRequest",
+    "ChallengeContentEditRequest",
+    "ChallengeCreateRequest",
+    "ChallengeTaskCreateRequest",
     "ConcernCreateRequest",
     "DyffEntityCreateRequest",
     "DyffEntityQueryRequest",
